@@ -153,6 +153,8 @@ class Request:
 
         max_results: limits the number of input granules processed in the request
 
+        concatenate: Whether to invoke a service that supports concatenation
+
     Returns:
         A Harmony Request instance
     """
@@ -172,7 +174,8 @@ class Request:
                  scale_size: List[float] = None,
                  shape: Optional[Tuple[IO, str]] = None,
                  variables: List[str] = ['all'],
-                 width: int = None):
+                 width: int = None,
+                 concatenate: bool = None):
         """Creates a new Request instance from all specified criteria.'
         """
         self.collection = collection
@@ -189,6 +192,7 @@ class Request:
         self.shape = shape
         self.variables = variables
         self.width = width
+        self.concatenate = concatenate
 
         self.variable_name_to_query_param = {
             'crs': 'outputcrs',
@@ -201,10 +205,12 @@ class Request:
             'height': 'height',
             'format': 'format',
             'max_results': 'maxResults',
+            'concatenate': 'concatenate'
         }
 
         self.spatial_validations = [
-            (lambda bb: bb.s < bb.n, 'Southern latitude must be less than Northern latitude'),
+            (lambda bb: bb.s <= bb.n, ('Southern latitude must be less than '
+                                       'or equal to Northern latitude')),
             (lambda bb: bb.s >= -90.0, 'Southern latitude must be greater than -90.0'),
             (lambda bb: bb.n >= -90.0, 'Northern latitude must be greater than -90.0'),
             (lambda bb: bb.s <= 90.0, 'Southern latitude must be less than 90.0'),
@@ -582,12 +588,16 @@ class Client:
                 'numInputGranules'
             ]
             status_subset = {k: v for k, v in response.json().items() if k in fields}
+            created_at_dt = dateutil.parser.parse(status_subset['createdAt'])
+            updated_at_dt = dateutil.parser.parse(status_subset['updatedAt'])
             return {
                 'status': status_subset['status'],
                 'message': status_subset['message'],
                 'progress': status_subset['progress'],
-                'created_at': dateutil.parser.parse(status_subset['createdAt']),
-                'updated_at': dateutil.parser.parse(status_subset['updatedAt']),
+                'created_at': created_at_dt,
+                'updated_at': updated_at_dt,
+                'created_at_local': created_at_dt.replace(microsecond=0).astimezone().isoformat(),
+                'updated_at_local': updated_at_dt.replace(microsecond=0).astimezone().isoformat(),
                 'request': status_subset['request'],
                 'num_input_granules': int(status_subset['numInputGranules']),
             }
